========
Examples
========

.. toctree::
  :maxdepth: 2


.. fancy_include:: tif_hologram.py

.. fancy_include:: hyperspy_hologram.py

.. fancy_include:: convert_txt2npy.py

.. fancy_include:: convert_txt2tif.py
